@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 package Games::Mastermind::Cracker::Random;
 use Moose;
 extends 'Games::Mastermind::Cracker';
@@ -8,11 +7,13 @@ sub make_guess {
     join '', map { $self->random_peg } 1 .. $self->holes;
 }
 
+1;
+
+__END__
+
 =head1 NAME
 
 Games::Mastermind::Cracker::Random - make completely random guesses
 
 =cut
 
-1;
-
